<?php

namespace Drupal\services_token\Plugin\ServiceDefinition;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\services\ServiceDefinitionBase;
use Drupal\services_token\TokenGeneratorInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Route;
use Symfony\Component\Serializer\SerializerInterface;

/**
 * @ServiceDefinition(
 *   id = "services_token_generate",
 *   methods = {
 *     "POST"
 *   },
 *   title = @Translation("Generate services token"),
 *   description = @Translation("Generate a service token and return the token record."),
 *   category = @Translation("Services Token"),
 *   path = "services_token/generate"
 * )
 */
class TokenGenerate extends ServiceDefinitionBase implements ContainerFactoryPluginInterface {

  /**
   * Services token generator.
   *
   * @var \Drupal\services_token\TokenGeneratorInterface
   */
  protected $tokenGenerator;

  /**
   * Constructs a token generate services.
   *
   * @param \Drupal\services_token\TokenGeneratorInterface $token_generator
   *   The services token generator.
   */
  public function __construct(
    $configuration,
    $plugin_id,
    $plugin_definition,
    TokenGeneratorInterface $token_generator
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->tokenGenerator = $token_generator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(
    ContainerInterface $container,
    array $configuration,
    $plugin_id,
    $plugin_definition
  ) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('services_token.token_generator'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processRoute(Route $route) {
    $route->setRequirement('_permission', 'generate services token');
  }

  /**
   * {@inheritdoc}
   */
  public function processRequest(
    Request $request,
    RouteMatchInterface $route_match,
    SerializerInterface $serializer
  ) {
    return $this->tokenGenerator->generate();
  }

}
